package Data::RandomPerson::Names::Female;

use strict;
use warnings;

use base 'Data::RandomPerson::Names';

use Data::RandomPerson::Choice;

sub new {
    my ($class) = @_;

    my $self = bless {}, $class;

    $self->{choice} = Data::RandomPerson::Choice->new();

    my @names = <DATA>;
    close DATA;
    chomp (@names);
    $self->{choice}->add_list(@names);

    return $self;
}

1;

=pod

=head1 NAME

Data::RandomPerson::Names::Female - A list of female names from some census data

=head1 SYNOPSIS

  use Data::RandomPerson::Names::Female;

  my $f = Data::RandomPerson::Names::Female->new();

  print $f->get();

=head1 DESCRIPTION

=head2 Overview

Returns a random element from a list of female names culled from some census data.

=head2 Constructors and initialization

=over 4

=item new( )

Create the Data::RandomPerson::Names::Female object.

=back

=head2 Class and object methods

=over 4

=item get( )

Returns a random name from the list.

=item size( )

Returns the size of the list

=back

=head1 AUTHOR

Peter Hickman (peterhi@ntlworld.com)

=head1 COPYRIGHT

Copyright (c) 2005, Peter Hickman. This module is
free software. It may be used, redistributed and/or modified under the
same terms as Perl itself.

=cut

__DATA__
abbey
abbie
abby
abigail
ada
adah
adaline
addie
adela
adelaida
adelaide
adele
adelia
adelina
adeline
adell
adella
adelle
adena
adina
adria
adriana
adriane
adrianna
adrianne
adrien
adriene
adrienne
afton
agatha
agnes
agnus
agripina
agueda
agustina
ai
aida
aide
aiko
aileen
ailene
aimee
aisha
aja
akiko
akilah
alaina
alaine
alana
alane
alanna
alayna
alba
alberta
albertha
albertina
albertine
albina
alda
alease
alecia
aleen
aleida
aleisha
alejandra
alejandrina
alena
alene
alesha
aleshia
alesia
alessandra
aleta
aletha
alethea
alethia
alexa
alexandra
alexandria
alexia
alfreda
alfredia
alia
alica
alice
alicia
alida
alina
aline
alisa
alise
alisha
alishia
alisia
alison
alissa
alita
alix
aliza
alla
alleen
allegra
allena
allene
allie
alline
allison
allyn
allyson
alma
almeda
almeta
alona
alpha
alta
altagracia
altha
althea
alvera
alverta
alvina
alyce
alycia
alysa
alyse
alysha
alysia
alyson
alyssa
amada
amal
amalia
amanda
amber
amberly
amee
amelia
america
ami
amie
amiee
amina
amira
ammie
amparo
amy
an
ana
anabel
analisa
anamaria
anastacia
anastasia
andera
andra
andree
andria
anette
angela
angele
angelena
angeles
angelia
angelic
angelica
angelika
angelina
angeline
angelique
angelita
angella
angelyn
angie
angila
angla
angle
anglea
anh
anika
anisa
anisha
anissa
anita
anitra
anja
anjanette
anjelica
ann
anna
annabel
annabell
annabelle
annalee
annalisa
annamae
annamaria
annamarie
anne
anneliese
annelle
annemarie
annett
annetta
annette
annice
annie
annika
annis
annita
annmarie
antionette
antoinette
antonetta
antonette
antonietta
antonina
anya
apolonia
april
apryl
ara
araceli
aracelis
aracely
arcelia
ardath
ardelia
ardell
ardella
ardelle
ardis
ardith
aretha
argelia
argentina
ariana
ariane
arianna
arianne
arica
arie
arielle
arla
arlean
arleen
arlena
arlene
arletha
arletta
arlette
arlinda
arline
arlyne
armanda
armandina
armida
arminda
arnetta
arnette
arnita
artie
arvilla
asha
ashanti
ashely
ashlea
ashlee
ashleigh
ashli
ashlie
ashly
ashlyn
ashton
asia
asley
assunta
astrid
asuncion
athena
audie
audra
audrea
audrey
audria
audrie
audry
augusta
augustina
aundrea
aura
aurea
aurelia
aurora
aurore
autumn
ava
avelina
avis
avril
awilda
ayako
ayana
ayanna
ayesha
azalee
azucena
azzie
babara
babette
bailey
bambi
bao
barabara
barb
barbar
barbara
barbera
barbie
barbra
bari
barrie
basilia
bea
beata
beatrice
beatris
beatriz
beaulah
bebe
becki
beckie
becky
bee
belen
belia
belinda
belkis
bell
bella
belle
belva
benita
berenice
berna
bernadette
bernadine
bernarda
bernardina
bernardine
berneice
bernetta
bernice
berniece
bernita
berta
bertha
bertie
beryl
bess
bessie
beth
bethanie
bethann
bethany
bethel
betsey
betsy
bette
bettie
bettina
betty
bettyann
bettye
beula
beulah
bev
beverlee
beverley
beverly
bianca
bibi
billi
billye
birdie
birgit
blanca
blanch
blanche
blondell
blossom
blythe
bobbi
bobbye
bobette
bok
bong
bonita
bonnie
bonny
branda
brande
brandee
brandi
brandie
brandy
breana
breann
breanna
breanne
bree
brenda
brenna
briana
brianna
brianne
bridget
bridgett
bridgette
brigette
brigid
brigida
brigitte
brinda
britany
britney
britni
britta
brittaney
brittani
brittanie
brittany
britteny
brittney
brittni
brittny
bronwyn
brook
brooke
bruna
brunilda
bryanna
brynn
buena
buffy
bula
bulah
bunny
burma
caitlin
caitlyn
calandra
calista
callie
camelia
camellia
cami
camie
camila
camilla
camille
cammie
cammy
candace
candance
candelaria
candi
candice
candida
candie
candis
candra
candy
candyce
caprice
cara
caren
cari
caridad
carie
carin
carina
carisa
carissa
carita
carla
carlee
carleen
carlena
carlene
carletta
carley
carli
carlie
carline
carlita
carlota
carlotta
carly
carlyn
carma
carman
carmel
carmela
carmelia
carmelina
carmelita
carmella
carmina
carmon
carola
carolann
carole
carolee
carolin
carolina
caroline
caroll
carolyn
carolyne
carolynn
caron
caroyln
carri
carrie
carry
caryl
carylon
caryn
casandra
casie
casimira
cassandra
cassaundra
cassey
cassi
cassidy
cassie
cassondra
cassy
catalina
catarina
caterina
catharine
catherin
catherina
catherine
cathern
catheryn
cathey
cathi
cathie
cathleen
cathrine
cathryn
cathy
catina
catrice
catrina
cayla
cecelia
cecila
cecile
cecilia
cecille
cecily
celena
celesta
celeste
celestina
celestine
celia
celina
celinda
celine
celsa
ceola
chae
chan
chana
chanda
chandra
chanel
chanell
chanelle
chantal
chantay
chante
chantel
chantell
chantelle
chara
charis
charise
charissa
charisse
charita
charity
charla
charleen
charlena
charlene
charlesetta
charlette
charline
charlott
charlotte
charlsie
charlyn
charmain
charmaine
charolette
chasidy
chasity
chassidy
chastity
chau
chaya
chelsea
chelsey
chelsie
cher
chere
cheree
cherelle
cheri
cherie
cherilyn
cherise
cherish
cherly
cherlyn
cherri
cherrie
cherry
cherryl
chery
cheryl
cheryle
cheryll
cheyenne
chia
chieko
chin
china
ching
chiquita
chloe
chrissy
christa
christal
christeen
christel
christen
christena
christene
christi
christia
christiana
christiane
christie
christin
christina
christine
christinia
christy
chrystal
chu
chun
ciara
cicely
ciera
cierra
cinda
cinderella
cindi
cindie
cindy
cinthia
cira
claire
clara
clare
claretha
claretta
claribel
clarice
clarinda
clarine
claris
clarisa
clarissa
clarita
classie
claudette
claudia
claudie
claudine
clelia
clemencia
clementina
clementine
clemmie
cleopatra
cleora
cleotilde
cleta
clora
clorinda
clotilde
codi
coleen
colene
coletta
colette
colleen
collen
collene
collette
concepcion
conception
concetta
concha
conchita
constance
consuela
consuelo
contessa
cora
coral
coralee
coralie
corazon
cordelia
cordia
cordie
coreen
corene
coretta
cori
corie
corina
corine
corinna
corinne
corliss
cornelia
corrie
corrin
corrina
corrine
corrinne
cortney
creola
cris
criselda
crissy
crista
cristal
cristen
cristi
cristie
cristin
cristina
cristine
cristy
crysta
crystal
crystle
cuc
cyndi
cyndy
cynthia
cyrstal
cythia
dacia
dagmar
dagny
dahlia
daina
daine
daisey
daisy
dakota
dalene
dalia
dalila
damaris
danae
danelle
danette
dani
dania
danica
daniela
daniele
daniell
daniella
danielle
danika
danille
danita
dann
danna
dannette
dannielle
danuta
danyel
danyell
danyelle
daphine
daphne
dara
darby
darcel
darcey
darci
darcie
darcy
daria
darla
darleen
darlena
darlene
darline
davida
davina
dawn
dawna
dawne
dayle
dayna
daysi
deadra
deana
deandra
deandrea
deane
deann
deanna
deanne
deb
debbi
debbie
debbra
debby
debera
debi
debora
deborah
debra
debrah
debroah
dede
dedra
deeann
deeanna
deedee
deedra
deena
deetta
deidra
deidre
deirdre
deja
delaine
delana
delcie
delena
delfina
delia
delicia
delila
delilah
delinda
delisa
dell
della
delma
delmy
delois
deloise
delora
deloras
delores
deloris
delorse
delpha
delphia
delphine
delsie
delta
demetra
demetria
demetrice
dena
denae
deneen
denese
denice
denise
denisha
denisse
denita
denna
dennise
denyse
deonna
desirae
desire
desiree
despina
dessie
destiny
detra
devona
devora
devorah
dia
diamond
dian
diana
diane
diann
dianna
dianne
diedra
diedre
dierdre
digna
dimple
dina
dinah
dinorah
dione
dionna
dionne
divina
dixie
dodie
dollie
dolly
dolores
doloris
domenica
dominga
dominica
dominque
domitila
domonique
dona
donella
donetta
donette
donita
donna
donnetta
donnette
donya
dora
dorathy
dorcas
doreatha
doreen
dorene
doretha
dorethea
doretta
dori
doria
dorie
dorinda
dorine
doris
dorla
dorotha
dorothea
dorothy
dorris
dortha
dorthea
dorthey
dorthy
dot
dottie
dotty
dovie
dreama
drema
drucilla
drusilla
dulce
dulcie
dung
dusti
dwana
dyan
earlean
earleen
earlene
earlie
earline
earnestine
eartha
easter
eboni
ebonie
ebony
echo
eda
edda
edelmira
eden
edie
edith
edna
edra
edris
edwina
edyth
edythe
effie
ehtel
eileen
eilene
ela
eladia
elaina
elaine
elana
elane
elanor
elayne
elba
elda
eldora
eleanor
eleanora
eleanore
elease
elena
elene
eleni
elenor
elenora
elenore
eleonor
eleonora
eleonore
elfreda
elfrieda
elfriede
elia
eliana
elicia
elida
elidia
elin
elina
elinor
elinore
elisa
elisabeth
elise
elissa
eliz
eliza
elizabet
elizabeth
elizbeth
elizebeth
elke
ella
ellamae
ellan
ellen
ellena
elli
ellie
elly
ellyn
elma
elmira
elna
elnora
elodia
elois
eloisa
eloise
elouise
elsa
else
elsie
elsy
elva
elvera
elvia
elvie
elvina
elvira
elwanda
elyse
elza
ema
emelda
emelia
emelina
emeline
emely
emerald
emerita
emiko
emilee
emilia
emilie
emily
emma
emmaline
emmie
emmy
emogene
ena
enda
enedina
eneida
enid
enola
enriqueta
epifania
era
erica
ericka
erika
erinn
erlene
erlinda
erline
erma
ermelinda
erminia
erna
ernestina
ernestine
eryn
esmeralda
esperanza
essie
esta
estefana
estela
estell
estella
estelle
ester
esther
estrella
etha
ethel
ethelene
ethelyn
ethyl
etsuko
etta
ettie
eufemia
eugena
eugenia
eugenie
eula
eulah
eulalia
eun
euna
eunice
eura
eusebia
eustolia
eva
evalyn
evangelina
evangeline
eve
evelia
evelin
evelina
eveline
evelyn
evelyne
evelynn
evette
evia
evie
evita
evon
evonne
ewa
exie
fabiola
fae
fairy
faith
fallon
fannie
fanny
farah
farrah
fatima
fatimah
faustina
faviola
fawn
fay
faye
fe
felecia
felica
felice
felicia
felicidad
felicita
felicitas
felipa
felisa
felisha
fermina
fern
fernanda
fernande
ferne
fidela
fidelia
filomena
fiona
flavia
fleta
flo
flor
flora
florance
florence
florencia
florene
florentina
floretta
floria
florida
florinda
florine
florrie
flossie
floy
fonda
fran
france
francene
francesca
franchesca
francie
francina
francine
francisca
francoise
fransisca
freda
fredda
frederica
fredericka
fredia
fredricka
freeda
freida
frida
frieda
fumiko
gabriela
gabriele
gabriella
gabrielle
gala
galina
garnet
garnett
gay
gaye
gayla
gaylene
gaynell
gaynelle
gearldine
gema
gemma
gena
genesis
geneva
genevie
genevieve
genevive
genia
genie
genna
gennie
genny
genoveva
georgann
georgeann
georgeanna
georgene
georgetta
georgette
georgia
georgiana
georgiann
georgianna
georgianne
georgie
georgina
georgine
geraldine
geralyn
gerda
geri
germaine
gerri
gertha
gertie
gertrud
gertrude
gertrudis
gertude
ghislaine
gia
gianna
gidget
gigi
gilberte
gilda
gillian
gilma
gina
ginette
ginger
ginny
giovanna
gisela
gisele
giselle
gita
giuseppina
gladis
glady
gladys
glayds
glenda
glendora
glenna
glennie
glennis
glinda
gloria
glory
glynda
glynis
golda
golden
goldie
grace
gracia
gracie
graciela
grayce
grazyna
gregoria
greta
gretchen
gretta
gricelda
grisel
griselda
gudrun
guillermina
gussie
gwen
gwenda
gwendolyn
gwenn
gwyn
gwyneth
ha
hae
hailey
haley
halina
halley
hallie
han
hana
hang
hanh
hanna
hannah
hannelore
harmony
harriet
harriett
harriette
hassie
hattie
haydee
hayley
hazel
heather
hedwig
hedy
hee
heide
heidi
heidy
heike
helaine
helen
helena
helene
helga
hellen
henrietta
henriette
herlinda
herma
hermelinda
hermila
hermina
hermine
herminia
herta
hertha
hester
hettie
hiedi
hien
hilaria
hilary
hilda
hilde
hildegard
hildegarde
hildred
hillary
hilma
hiroko
hisako
hoa
holley
holli
hollie
holly
honey
hope
hortencia
hortense
hortensia
hsiu
hue
hui
hulda
huong
hwa
hyacinth
hye
hyo
hyon
hyun
ida
idalia
idell
idella
iesha
ignacia
ila
ilana
ilda
ileana
ileen
ilene
iliana
illa
ilona
ilse
iluminada
ima
imelda
imogene
in
ina
india
indira
inell
ines
inez
inga
inge
ingeborg
inger
ingrid
inocencia
iola
iona
ione
iraida
irena
irene
irina
iris
irish
irma
irmgard
isa
isabel
isabell
isabella
isabelle
isadora
isaura
isela
isidra
isis
isobel
iva
ivana
ivelisse
ivette
ivey
ivonne
ivy
izetta
izola
ja
jacalyn
jacelyn
jacinda
jacinta
jackeline
jackelyn
jacki
jacklyn
jackqueline
jaclyn
jacqualine
jacque
jacquelin
jacqueline
jacquelyn
jacquelyne
jacquelynn
jacquetta
jacqui
jacquie
jacquiline
jacquline
jacqulyn
jada
jade
jadwiga
jaimee
jaimie
jaleesa
jalisa
jama
jamee
jami
jamika
jamila
jammie
jana
janae
janay
jane
janean
janee
janeen
janel
janell
janella
janelle
janene
janessa
janet
janeth
janett
janetta
janette
janey
jani
janice
janie
janiece
janina
janine
janis
janise
janita
jann
janna
jannet
jannette
jannie
january
janyce
jaqueline
jaquelyn
jasmin
jasmine
jaunita
jaye
jayme
jaymie
jayna
jayne
jazmin
jazmine
jeana
jeane
jeanelle
jeanene
jeanett
jeanetta
jeanette
jeanice
jeanie
jeanine
jeanmarie
jeanna
jeanne
jeannetta
jeannette
jeannie
jeannine
jeffie
jen
jena
jenae
jene
jenee
jenell
jenelle
jenette
jeneva
jeni
jenice
jenifer
jeniffer
jenine
jenise
jenna
jennefer
jennell
jennette
jenni
jennie
jennifer
jenniffer
jennine
jenny
jeraldine
jeri
jerica
jerilyn
jerlene
jerri
jerrica
jerrie
jesenia
jesica
jessenia
jessi
jessia
jessica
jessika
jestine
jesusa
jesusita
jetta
jettie
ji
jill
jillian
jin
jina
jinny
jo
joana
joane
joanie
joann
joanna
joanne
joannie
joaquina
jocelyn
jodee
jodi
jodie
joeann
joella
joelle
joellen
joetta
joette
johana
johanna
johanne
johna
johnetta
johnette
johnna
johnsie
joi
joie
jolanda
joleen
jolene
jolie
joline
jolyn
jolynn
jona
jone
jonell
jonelle
jong
joni
jonie
jonna
jonnie
josefa
josefina
josefine
joselyn
josephina
josephine
josette
josie
joslyn
josphine
jovan
jovita
joy
joya
joyce
joycelyn
joye
juana
juanita
judi
judie
judith
judy
jule
julee
julene
juli
julia
juliana
juliane
juliann
julianna
julianne
julie
julieann
julienne
juliet
julieta
julietta
juliette
julissa
june
jung
junie
junita
junko
justa
justina
justine
jutta
ka
kacey
kaci
kacie
kacy
kai
kaila
kaitlin
kaitlyn
kala
kaleigh
kaley
kali
kallie
kalyn
kam
kamala
kami
kamilah
kandace
kandi
kandice
kandis
kandra
kandy
kanesha
kanisha
kara
karan
kareen
karen
karena
karey
kari
karie
karima
karin
karina
karine
karisa
karissa
karla
karleen
karlene
karly
karlyn
karma
karmen
karol
karole
karoline
karolyn
karon
karren
karri
karrie
karry
kary
karyl
karyn
kasandra
kasha
kasi
kasie
kassandra
kassie
kate
katelin
katelyn
katelynn
katerine
kathaleen
katharina
katharine
katharyn
kathe
katheleen
katherin
katherina
katherine
kathern
katheryn
kathey
kathi
kathie
kathleen
kathlene
kathline
kathlyn
kathrin
kathrine
kathryn
kathryne
kathy
kathyrn
kati
katia
katie
katina
katlyn
katrice
katrina
kattie
katy
kay
kayce
kaycee
kaye
kayla
kaylee
kayleen
kayleigh
kaylene
kazuko
kecia
keeley
keely
keena
keesha
keiko
keila
keira
keisha
keitha
keli
kelle
kellee
kelli
kellie
kellye
kelsey
kelsi
kelsie
kemberly
kena
kenda
kendal
kendra
kenia
kenisha
kenna
kenya
kenyatta
kenyetta
kera
keren
keri
kerri
kerrie
kerstin
kesha
keshia
keturah
keva
khadijah
khalilah
kia
kiana
kiara
kiera
kiersten
kiesha
kiley
kimber
kimberely
kimberlee
kimberley
kimberli
kimberlie
kimberly
kimbery
kimbra
kimi
kimiko
kina
kindra
kira
kirsten
kirstie
kirstin
kisha
kit
kittie
kitty
kiyoko
kizzie
kizzy
klara
kori
kortney
kourtney
krishna
krissy
krista
kristal
kristan
kristeen
kristel
kristen
kristi
kristian
kristie
kristin
kristina
kristine
kristle
kristy
kristyn
krysta
krystal
krysten
krystin
krystina
krystle
krystyna
kum
kyla
kylee
kylie
kym
kymberly
kyoko
kyong
kyra
kyung
lacey
lachelle
laci
lacie
lacresha
ladawn
ladonna
lady
lael
lahoma
lai
laila
laine
lajuana
lakeesha
lakeisha
lakendra
lakenya
lakesha
lakeshia
lakia
lakiesha
lakisha
lakita
lala
lamonica
lan
lana
lanell
lanelle
lanette
lang
lani
lanie
lanita
lannie
lanora
laquanda
laquita
lara
larae
laraine
laree
larhonda
larisa
larissa
larita
laronda
larraine
larue
lasandra
lashanda
lashandra
lashaun
lashaunda
lashawn
lashawna
lashawnda
lashay
lashell
lashon
lashonda
lashunda
lasonya
latanya
latarsha
latasha
latashia
latesha
latia
laticia
latina
latisha
latonia
latonya
latoria
latosha
latoya
latoyia
latrice
latricia
latrina
latrisha
launa
laura
lauralee
lauran
laure
laureen
laurel
laurena
laurene
lauretta
laurette
lauri
laurice
laurie
laurinda
laurine
lauryn
lavada
lavelle
lavenia
lavera
laverna
laveta
lavette
lavina
lavinia
lavon
lavona
lavonda
lavone
lavonia
lavonna
lavonne
lawana
lawanda
lawanna
layla
layne
le
lea
leah
lean
leana
leandra
leann
leanna
leanne
leanora
leatha
leatrice
lecia
leda
leeann
leeanna
leeanne
leena
leesa
leia
leida
leigha
leighann
leila
leilani
leisa
leisha
lekisha
lela
lelah
lelia
lena
lenita
lenna
lennie
lenora
lenore
leola
leoma
leona
leonarda
leone
leonia
leonida
leonie
leonila
leonor
leonora
leonore
leontine
leora
leota
lera
lesa
lesha
lesia
leslee
lesli
lessie
leta
letha
leticia
letisha
letitia
lettie
letty
lexie
lezlie
li
lia
liana
liane
lianne
libbie
libby
liberty
librada
lida
lidia
lien
lieselotte
ligia
lila
lili
lilia
lilian
liliana
lilla
lilli
lillia
lilliam
lillian
lilliana
lillie
lilly
lily
lin
lina
linda
lindsy
lindy
linette
ling
linh
linn
linnea
linnie
linsey
lisa
lisabeth
lisandra
lisbeth
lise
lisette
lisha
lissa
lissette
lita
livia
liz
liza
lizabeth
lizbeth
lizeth
lizette
lizzette
lizzie
loan
loida
lois
loise
lola
lolita
loma
lona
londa
loni
lonna
lora
loraine
loralee
lore
lorean
loree
loreen
lorelei
lorena
lorene
lorenza
loreta
loretta
lorette
lori
loria
loriann
lorie
lorilee
lorina
lorinda
lorine
loris
lorita
lorna
lorraine
lorretta
lorri
lorriane
lorrie
lorrine
lory
lottie
louann
louanne
louella
louetta
louisa
louise
loura
lourdes
lourie
louvenia
love
lovella
lovetta
lovie
loyce
lu
luana
luann
luanna
luanne
luba
luci
lucia
luciana
lucie
lucienne
lucila
lucile
lucilla
lucille
lucina
lucinda
lucrecia
lucretia
lucy
ludie
ludivina
lue
luella
luetta
luisa
luise
lula
lulu
luna
lupita
lura
lurlene
lurline
luvenia
luz
lyda
lydia
lyla
lyn
lynda
lyndia
lyndsay
lyndsey
lynell
lynelle
lynetta
lynette
lynna
lynne
lynnette
lynsey
ma
mabel
mabelle
mable
machelle
macie
mackenzie
macy
madalene
madaline
madalyn
maddie
madelaine
madeleine
madelene
madeline
madelyn
madge
madie
madison
madlyn
madonna
mae
maegan
mafalda
magali
magaly
magan
magaret
magda
magdalen
magdalena
magdalene
magen
maggie
magnolia
mahalia
mai
maia
maida
maile
maira
maire
maisha
maisie
majorie
makeda
malena
malia
malika
malinda
malisa
malissa
malka
mallie
mallory
malorie
malvina
mamie
mammie
mana
manda
mandi
mandie
mandy
manie
manuela
many
mao
maple
mara
maragaret
maragret
maranda
marcela
marcelene
marcelina
marceline
marcell
marcella
marcelle
marcene
marchelle
marci
marcia
marcie
marcy
mardell
maren
marg
margaret
margareta
margarete
margarett
margaretta
margarette
margarita
margarite
margart
marge
margene
margeret
margert
margery
marget
margherita
margie
margit
margo
margorie
margot
margret
margrett
marguerita
marguerite
margurite
margy
marhta
mari
mariah
mariam
marian
mariana
marianela
mariann
marianna
marianne
maribel
maribeth
marica
maricela
maricruz
marie
mariel
mariela
mariella
marielle
marietta
mariette
mariko
marilee
marilou
marilu
marilyn
marilynn
marin
marina
marinda
marine
maris
marisa
marisela
marisha
marisol
marissa
marita
maritza
marivel
marjorie
marjory
marketta
markita
marla
marlana
marleen
marlen
marlena
marlene
marline
marlo
marlyn
marlys
marna
marni
marnie
marquerite
marquetta
marquita
marquitta
marry
marsha
marta
marth
martha
marti
martina
martine
marva
marvel
marvella
marvis
marx
marya
maryalice
maryam
maryann
maryanna
maryanne
marybelle
marybeth
maryellen
maryetta
maryjane
maryjo
maryland
marylee
marylin
maryln
marylou
marylouise
marylyn
marylynn
maryrose
masako
matha
mathilda
mathilde
matilda
matilde
mattie
maud
maude
maudie
maura
maureen
maurine
maurita
mavis
maxie
maxima
maximina
maxine
may
maya
maybell
maybelle
maye
mayme
mayola
mayra
mazie
mckenzie
meagan
meaghan
mechelle
meda
mee
meg
megan
meggan
meghan
meghann
mei
melaine
melani
melania
melanie
melany
melba
melda
melia
melida
melina
melinda
melisa
melissa
melissia
melita
mellie
mellisa
mellissa
melodee
melodi
melodie
melody
melonie
melony
melva
melvina
melynda
mendy
mercedes
mercedez
mercy
meredith
meri
merideth
meridith
merilyn
merissa
merlene
merlyn
merna
merri
merrie
merrilee
merry
mertie
meryl
meta
mi
mia
mica
micaela
micha
michaela
michaele
michele
michelina
micheline
michell
michelle
michiko
micki
mickie
miesha
migdalia
mignon
miguelina
mika
mikaela
miki
mikki
mila
milagro
milagros
milda
mildred
milissa
millicent
millie
milly
mimi
min
mina
minda
mindi
mindy
minerva
ming
minna
minnie
minta
mira
miranda
mireille
mirella
mireya
miriam
mirian
mirna
mirta
mirtha
misha
miss
missy
misti
mistie
misty
mitsue
mitsuko
mittie
mitzi
mitzie
miyoko
modesta
moira
mollie
molly
mona
monet
monica
monika
monique
monnie
monserrate
moon
mora
moriah
mozell
mozella
mozelle
mui
muoi
muriel
my
myesha
myong
myra
myriam
myrl
myrle
myrna
myrta
myrtice
myrtie
myrtis
myrtle
myung
na
nada
nadene
nadia
nadine
naida
nakesha
nakia
nakisha
nakita
nam
nan
nana
nancee
nancey
nanci
nancie
nancy
nanette
nannette
nannie
naoma
naomi
narcisa
natacha
natalia
natalie
natalya
natasha
natashia
nathalie
natisha
natividad
natosha
necole
neda
nedra
neely
neida
nelda
nelia
nelida
nell
nella
nelle
nellie
nelly
nena
nenita
neoma
neomi
nereida
nerissa
nery
neta
nettie
neva
nevada
nga
ngan
ngoc
nguyet
nia
nichelle
nichol
nichole
nicholle
nicki
nickie
nickole
nicol
nicola
nicolasa
nicole
nicolette
nicolle
nida
nidia
niesha
nieves
niki
nikia
nikita
nikki
nikole
nila
nilda
nilsa
nina
ninfa
nisha
nita
nobuko
noelia
noella
noelle
noemi
nohemi
nola
noma
nona
nora
norah
noreen
norene
noriko
norine
norma
nova
novella
nu
nubia
nydia
nyla
obdulia
ocie
octavia
oda
odelia
odessa
odette
odilia
ofelia
ok
ola
olene
oleta
olevia
olga
olimpia
olinda
oliva
olive
olivia
olympia
oma
omega
ona
oneida
onie
onita
opal
ophelia
ora
oralee
oralia
oretha
orpha
ossie
otelia
otilia
ouida
ozell
ozella
ozie
pa
page
paige
palma
palmira
pam
pamala
pamela
pamelia
pamella
pamila
pamula
pandora
pansy
paola
parthenia
particia
pasty
patience
patria
patrica
patrice
patrina
patsy
patti
pattie
patty
paula
paulene
pauletta
paulette
paulina
pauline
paulita
paz
pearl
pearle
pearlene
pearlie
pearline
pearly
peg
peggie
peggy
pei
penelope
penney
penni
pennie
penny
perla
petra
petrina
petronila
phebe
phillis
philomena
phoebe
phung
phuong
phylicia
phylis
phyliss
phyllis
pia
piedad
pilar
ping
pinkie
piper
pok
polly
porsche
porsha
portia
precious
pricilla
princess
priscila
priscilla
providencia
prudence
pura
qiana
queen
queenie
quiana
quyen
rachael
rachal
racheal
rachel
rachele
rachell
rachelle
racquel
rae
raeann
raelene
rafaela
raguel
raina
raisa
ramona
ramonita
rana
ranae
randa
randee
randi
ranee
raquel
rasheeda
rashida
raven
raye
raylene
raymonde
rayna
rea
reagan
reanna
reatha
reba
rebbeca
rebbecca
rebeca
rebecca
rebecka
rebekah
reda
reena
refugia
regan
regena
regenia
regina
regine
reginia
reiko
reina
reita
rema
remedios
remona
rena
renae
renata
renate
renay
renda
renea
renee
renetta
renita
renna
ressie
reta
retha
retta
reva
reyna
reynalda
rhea
rheba
rhiannon
rhoda
rhona
rhonda
ria
ricarda
richelle
ricki
rikki
rima
rina
risa
rita
riva
rivka
robbi
robbin
robbyn
robena
roberta
robyn
rochel
rochell
rochelle
rocio
rolanda
rolande
roma
romaine
romana
romelia
romona
rona
ronda
roni
ronna
ronni
rosa
rosalba
rosalee
rosalia
rosalie
rosalina
rosalind
rosalinda
rosaline
rosalva
rosalyn
rosamaria
rosamond
rosana
rosann
rosanna
rosanne
rosaria
rosaura
rose
roseann
roseanna
roseanne
roselee
roselia
roseline
rosella
roselle
roselyn
rosemarie
rosemary
rosena
rosenda
rosetta
rosette
rosia
rosie
rosina
rosio
rosita
roslyn
rossana
rossie
rosy
rowena
roxana
roxane
roxann
roxanna
roxanne
roxie
roxy
rozanne
rozella
rubi
rubie
ruby
rubye
rufina
ruth
rutha
ruthann
ruthanne
ruthe
ruthie
ryann
sabina
sabine
sabra
sabrina
sacha
sachiko
sade
sadie
sadye
sage
salena
salina
salley
sallie
sally
salome
samantha
samara
samatha
samella
samira
sana
sanda
sandee
sandi
sandie
sandra
sanjuana
sanjuanita
sanora
santa
santana
santina
sara
sarah
sarai
saran
sari
sarina
sarita
sasha
saturnina
sau
saundra
savanna
savannah
scarlet
scarlett
season
sebrina
see
seema
selena
selene
selina
selma
sena
senaida
september
serafina
serena
serina
serita
setsuko
sha
shae
shaina
shakia
shakira
shakita
shala
shalanda
shalon
shalonda
shameka
shamika
shan
shana
shanae
shanda
shandi
shandra
shaneka
shanel
shanell
shanelle
shani
shanice
shanika
shaniqua
shanita
shanna
shannan
shanon
shanta
shantae
shantay
shante
shantel
shantell
shantelle
shanti
shaquana
shaquita
shara
sharan
sharda
sharee
sharell
sharen
shari
sharice
sharie
sharika
sharilyn
sharita
sharla
sharleen
sharlene
sharmaine
sharolyn
sharon
sharonda
sharri
sharron
sharyl
sharyn
shasta
shauna
shaunda
shaunna
shaunta
shaunte
shavon
shavonda
shavonne
shawana
shawanda
shawanna
shawna
shawnda
shawnee
shawnna
shawnta
shay
shayla
shayna
shea
sheba
sheena
sheila
sheilah
shela
shelba
shelia
shella
shelley
shelli
shellie
shelly
shemeka
shemika
shena
shenika
shenita
shenna
shera
sheree
sherell
sheri
sherice
sheridan
sherie
sherika
sherill
sherilyn
sherise
sherita
sherlene
sherley
sherly
sherlyn
sheron
sherrell
sherri
sherrie
sherril
sherrill
sherron
sherry
sherryl
shery
sheryl
sheryll
shiela
shila
shiloh
shin
shira
shirely
shirl
shirlee
shirleen
shirlene
shirly
shizue
shizuko
shona
shonda
shondra
shonna
shonta
shoshana
shu
shyla
sibyl
sierra
signe
sigrid
silva
silvana
silvia
sima
simona
simone
simonne
sina
sindy
siobhan
sirena
siu
sixta
skye
slyvia
so
socorro
sofia
soila
solange
soledad
somer
sommer
sona
sondra
song
sonia
sonja
sonya
soo
sook
soon
sophia
sophie
soraya
sparkle
spring
stacee
staci
stacia
stacie
star
starla
starr
stasia
stefani
stefania
stefanie
stefany
steffanie
stella
stepanie
stephaine
stephane
stephani
stephania
stephanie
stephany
stephenie
stephine
stephnie
stormy
su
suanne
sudie
sue
sueann
suellen
suk
sulema
sumiko
summer
sun
sunday
sunni
sunny
sunshine
susan
susana
susann
susanna
susannah
susanne
susie
susy
suzan
suzann
suzanna
suzanne
suzette
suzi
suzie
suzy
svetlana
sybil
syble
sylvia
sylvie
synthia
syreeta
ta
tabatha
tabetha
tabitha
tai
taina
taisha
tajuana
takako
takisha
talia
talisha
talitha
tam
tama
tamala
tamar
tamara
tamatha
tambra
tameika
tameka
tamekia
tamela
tamera
tamesha
tami
tamica
tamie
tamika
tamiko
tamisha
tammara
tammera
tammi
tammie
tammy
tamra
tana
tandra
tandy
taneka
tanesha
tangela
tania
tanika
tanisha
tanja
tanna
tanya
tara
tarah
taren
tari
tarra
tarsha
taryn
tasha
tashia
tashina
tasia
tatiana
tatum
tatyana
taunya
tawana
tawanda
tawanna
tawna
tawny
tawnya
tayna
teena
tegan
teisha
telma
temeka
temika
tempie
temple
tena
tenesha
tenisha
tennie
tennille
teodora
teofila
tequila
tera
tereasa
teresa
terese
teresia
teresita
teressa
teri
terica
terina
terisa
terra
terresa
terri
terrie
terrilyn
tesha
tess
tessa
tessie
thalia
thao
thea
theda
thelma
theodora
theola
theresa
therese
theresia
theressa
thersa
thi
thomasena
thomasina
thomasine
thora
thresa
thu
thuy
tia
tiana
tianna
tiara
tien
tiera
tierra
tiesha
tifany
tiffaney
tiffani
tiffanie
tiffany
tiffiny
tijuana
tilda
tillie
timika
tina
tinisha
tiny
tisa
tish
tisha
tobi
tobie
toccara
toi
tomasa
tomeka
tomi
tomika
tomiko
tommye
tomoko
tona
tonda
tonette
toni
tonia
tonie
tonisha
tonita
tonja
tonya
tora
tori
torie
torri
torrie
tosha
toshia
toshiko
tova
towanda
toya
tracee
traci
tracie
tran
trang
treasa
treena
trena
tresa
tressa
tressie
treva
tricia
trina
trinh
trinity
trish
trisha
trista
trudi
trudie
trudy
trula
tu
tula
tuyet
twana
twanda
twanna
twila
twyla
tyesha
tyisha
tynisha
tyra
ula
ulrike
un
una
ursula
usha
ute
vada
valarie
valda
valencia
valene
valentina
valeri
valeria
valerie
valery
vallie
valorie
valrie
vanda
vanesa
vanessa
vanetta
vania
vanita
vanna
vannesa
vannessa
vashti
vasiliki
veda
velda
velia
vella
velma
velva
velvet
vena
venessa
venetta
venice
venita
vennie
venus
veola
vera
verda
verdell
verdie
verena
vergie
verla
verlene
verlie
verline
verna
vernell
vernetta
vernia
vernice
vernie
vernita
verona
veronica
veronika
veronique
versie
vertie
vesta
veta
vi
vicenta
vickey
vicki
vickie
vicky
victoria
victorina
vida
viki
vikki
vilma
vina
vincenza
vinita
vinnie
viola
violet
violeta
violette
virgen
virgie
virgina
virginia
vita
viva
vivan
vivian
viviana
vivien
vivienne
voncile
vonda
vonnie
wai
waltraud
wan
wanda
waneta
wanetta
wanita
wava
wei
wen
wendi
wendie
wendolyn
wendy
wenona
whitley
wilda
wilhelmina
wilhemina
willa
willena
willene
willetta
willette
willia
williemae
willodean
willow
wilma
windy
winifred
winnie
winnifred
winona
winter
wonda
wynell
wynona
xenia
xiao
xiomara
xochitl
xuan
yadira
yaeko
yael
yahaira
yajaira
yan
yang
yanira
yasmin
yasmine
yasuko
yee
yelena
yen
yer
yesenia
yessenia
yetta
yevette
yi
ying
yoko
yolanda
yolande
yolando
yolonda
yon
yoshie
yoshiko
youlanda
yu
yuette
yuk
yuki
yukiko
yuko
yulanda
yun
yung
yuonne
yuri
yuriko
yvette
yvone
yvonne
zada
zaida
zana
zandra
zelda
zella
zelma
zena
zenaida
zenia
zenobia
zetta
zina
zita
zoe
zofia
zoila
zola
zona
zonia
zora
zoraida
zula
zulema
zulma
